@@ -11,6 +11,9 @@ class date(object):
     def getLastHourTime(self):
         return int(round(time.time() * 1000)) - 3600000
 
+    def getTimeSecond(self):
+        return int(round(time.time()))
+
     def getLastFiveYearTime(self):
         year = 365
         day = 24
